$.jqplot.Trendline

Plugin which will automatically compute and draw trendlines for plotted data.

Summary

$.jqplot.Trendline | Plugin which will automatically compute and draw trendlines for plotted data.
Properties |
show | Wether or not to show the trend line.
color | CSS color spec for the trend line.
renderer | Renderer to use to draw the trend line.
rendererOptions | Options to pass to the line renderer.
label | Label for the trend line to use in the legend.
type | Either ‘exponential’, ‘exp’, or ‘linear’.
shadow | true or false, whether or not to show the shadow.
markerRenderer | Renderer to use to draw markers on the line.
lineWidth | Width of the trend line.
shadowAngle | Angle of the shadow on the trend line.
shadowOffset | pixel offset for each stroke of the shadow.
shadowAlpha | Alpha transparency of the shadow.
shadowDepth | number of strokes to make of the shadow.

### Properties

### show

> this.show = $.jqplot.config.enablePlugins

Wether or not to show the trend line.

### color

> this.color = '#666666'

CSS color spec for the trend line. By default this wil be the same color as the primary line.

### renderer

> this.renderer = new $.jqplot.LineRenderer()

Renderer to use to draw the trend line. The data series that is plotted may not be rendered as a line. Therefore, we use our own line renderer here to draw a trend line.

### rendererOptions

> this.rendererOptions = {marker:{show:false}}

Options to pass to the line renderer. By default, markers are not shown on trend lines.

### label

> this.label = ''

Label for the trend line to use in the legend.

### type

> this.type = 'linear'

Either ‘exponential’, ‘exp’, or ‘linear’.

### shadow

> this.shadow = true

true or false, whether or not to show the shadow.

### markerRenderer

> this.markerRenderer = {show:false}

Renderer to use to draw markers on the line. I think this is wrong.

### lineWidth

> this.lineWidth = 1.5

Width of the trend line.

### shadowAngle

> this.shadowAngle = 45

Angle of the shadow on the trend line.

### shadowOffset

> this.shadowOffset = 1.0

pixel offset for each stroke of the shadow.

### shadowAlpha

> this.shadowAlpha = 0.07

Alpha transparency of the shadow.

### shadowDepth

> this.shadowDepth = 3

number of strokes to make of the shadow.

> this.show = $.jqplot.config.enablePlugins

Wether or not to show the trend line.

> this.color = '#666666'

CSS color spec for the trend line.

> this.renderer = new $.jqplot.LineRenderer()

Renderer to use to draw the trend line.

> this.rendererOptions = {marker:{show:false}}

Options to pass to the line renderer.

> this.label = ''

Label for the trend line to use in the legend.

> this.type = 'linear'

Either ‘exponential’, ‘exp’, or ‘linear’.

> this.shadow = true

true or false, whether or not to show the shadow.

> this.markerRenderer = {show:false}

Renderer to use to draw markers on the line.

> this.lineWidth = 1.5

Width of the trend line.

> this.shadowAngle = 45

Angle of the shadow on the trend line.

> this.shadowOffset = 1.0

pixel offset for each stroke of the shadow.

> this.shadowAlpha = 0.07

Alpha transparency of the shadow.

> this.shadowDepth = 3

number of strokes to make of the shadow.
Close